summaryrefslogtreecommitdiffstats
path: root/kuickshow
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:32:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:32:17 -0600
commitc509088a31cffd8e6d25c00a00414025426fc737 (patch)
tree06242637d2244aa79ad8812f39e64005ffc5ea91 /kuickshow
parent913e257dbbebe29c4f356ebb9fc6e888d0d1ac75 (diff)
downloadtdegraphics-c509088a31cffd8e6d25c00a00414025426fc737.tar.gz
tdegraphics-c509088a31cffd8e6d25c00a00414025426fc737.zip
Rename additional global TQt functions
Diffstat (limited to 'kuickshow')
-rw-r--r--kuickshow/src/aboutwidget.cpp2
-rw-r--r--kuickshow/src/imagewindow.cpp2
-rw-r--r--kuickshow/src/imlibwidget.cpp10
-rw-r--r--kuickshow/src/kuickimage.cpp14
-rw-r--r--kuickshow/src/kuickshow.cpp8
5 files changed, 18 insertions, 18 deletions
diff --git a/kuickshow/src/aboutwidget.cpp b/kuickshow/src/aboutwidget.cpp
index dc43578f..72ce1839 100644
--- a/kuickshow/src/aboutwidget.cpp
+++ b/kuickshow/src/aboutwidget.cpp
@@ -72,7 +72,7 @@ AboutWidget::AboutWidget( TQWidget *parent, const char *name )
else {
delete im;
im = 0L;
- qWarning( "KuickShow: about-image not found/unreadable." );
+ tqWarning( "KuickShow: about-image not found/unreadable." );
}
}
diff --git a/kuickshow/src/imagewindow.cpp b/kuickshow/src/imagewindow.cpp
index 12aa9118..39af7f51 100644
--- a/kuickshow/src/imagewindow.cpp
+++ b/kuickshow/src/imagewindow.cpp
@@ -288,7 +288,7 @@ void ImageWindow::setFullscreen( bool enable )
void ImageWindow::updateGeometry( int imWidth, int imHeight )
{
-// qDebug("::updateGeometry: %i, %i", imWidth, imHeight);
+// tqDebug("::updateGeometry: %i, %i", imWidth, imHeight);
// XMoveWindow( x11Display(), win, 0, 0 );
XResizeWindow( x11Display(), win, imWidth, imHeight );
diff --git a/kuickshow/src/imlibwidget.cpp b/kuickshow/src/imlibwidget.cpp
index 0bca3271..36420918 100644
--- a/kuickshow/src/imlibwidget.cpp
+++ b/kuickshow/src/imlibwidget.cpp
@@ -109,7 +109,7 @@ void ImlibWidget::init()
m_kuickFile = 0L;
if ( !id )
- qFatal("ImlibWidget: Imlib not initialized, aborting.");
+ tqFatal("ImlibWidget: Imlib not initialized, aborting.");
setAutoRender( true );
@@ -198,7 +198,7 @@ bool ImlibWidget::loadImage( KuickFile * file )
bool ImlibWidget::cacheImage( const KURL& url )
{
-// qDebug("cache image: %s", url.url().latin1());
+// tqDebug("cache image: %s", url.url().latin1());
KuickFile *file = FileCache::self()->getFile( url );
if ( file->isAvailable() )
return cacheImage( file );
@@ -213,7 +213,7 @@ bool ImlibWidget::cacheImage( const KURL& url )
bool ImlibWidget::cacheImage( KuickFile * file )
{
-// qDebug("cache image: %s", file->url().url().latin1());
+// tqDebug("cache image: %s", file->url().url().latin1());
KuickImage *kuim = loadImageInternal( file );
if ( kuim ) {
kuim->renderPixmap();
@@ -632,7 +632,7 @@ KuickImage * ImageCache::getKuimage( KuickFile * file,
// #ifndef NDEBUG
// gettimeofday( &tms2, NULL );
-// qDebug("*** LOADING image: %s, took %ld ms", file.latin1(),
+// tqDebug("*** LOADING image: %s, took %ld ms", file.latin1(),
// (tms2.tv_usec - tms1.tv_usec)/1000);
// #endif
@@ -655,7 +655,7 @@ KuickImage * ImageCache::getKuimage( KuickFile * file,
}
if ( kuickList.count() > (uint) myMaxImages ) {
-// qDebug(":::: now removing from cache: %s", (*fileList.fromLast()).latin1());
+// tqDebug(":::: now removing from cache: %s", (*fileList.fromLast()).latin1());
kuickList.removeLast();
fileList.remove( fileList.fromLast() );
}
diff --git a/kuickshow/src/kuickimage.cpp b/kuickshow/src/kuickimage.cpp
index 894a0369..db8065f9 100644
--- a/kuickshow/src/kuickimage.cpp
+++ b/kuickshow/src/kuickimage.cpp
@@ -47,7 +47,7 @@ void KuickImage::renderPixmap()
if ( !myIsDirty )
return;
-// qDebug("### rendering: %s", myFilename.latin1());
+// tqDebug("### rendering: %s", myFilename.latin1());
if ( myPixmap )
Imlib_free_pixmap( myId, myPixmap );
@@ -64,7 +64,7 @@ void KuickImage::renderPixmap()
// #ifndef NDEBUG
// gettimeofday( &tms2, NULL );
-// qDebug("*** rendering image: %s, took %ld ms", myFilename.latin1(),
+// tqDebug("*** rendering image: %s, took %ld ms", myFilename.latin1(),
// (tms2.tv_usec - tms1.tv_usec)/1000);
// #endif
@@ -164,7 +164,7 @@ void KuickImage::restoreOriginalSize()
if (myWidth == myOrigWidth && myHeight == myOrigHeight)
return;
-// qDebug("-- restoreOriginalSize");
+// tqDebug("-- restoreOriginalSize");
if ( myOrigIm != 0L )
{
@@ -200,7 +200,7 @@ void KuickImage::resize( int width, int height, KuickImage::ResizeMode mode )
void KuickImage::fastResize( int width, int height )
{
-// qDebug("-- fastResize: %i x %i", width, height );
+// tqDebug("-- fastResize: %i x %i", width, height );
// lazy resizing (only done when rendering pixmap)
myWidth = width;
@@ -210,7 +210,7 @@ void KuickImage::fastResize( int width, int height )
bool KuickImage::smoothResize( int newWidth, int newHeight )
{
-// qDebug("-- smoothResize: %i x %i", newWidth, newHeight);
+// tqDebug("-- smoothResize: %i x %i", newWidth, newHeight);
TQImage *image = newTQImage();
// Note: TQ_ScaleMin seems to have a bug (off-by-one, sometimes results in width being 1 pixel too small)
@@ -239,7 +239,7 @@ TQImage * KuickImage::newTQImage() const
{
ImlibImage *im;
-// qDebug("-- newTQImage");
+// tqDebug("-- newTQImage");
if ( myOrigIm != 0L && myRotation == ROT_0 && myFlipMode == FlipNone )
{
@@ -356,7 +356,7 @@ bool KuickImage::smoothResize( int newWidth, int newHeight )
basis_xx = (int) (4096.0 / scalex);
basis_yy = (int) (4096.0 / scaley);
- //qDebug("Basis: (%d, %d), (%d, 0), (0, %d)", basis_ox, basis_oy, basis_xx, basis_yy);
+ //tqDebug("Basis: (%d, %d), (%d, 0), (0, %d)", basis_ox, basis_oy, basis_xx, basis_yy);
int x2, y2;
diff --git a/kuickshow/src/kuickshow.cpp b/kuickshow/src/kuickshow.cpp
index 2ac6307a..9c8bdf1e 100644
--- a/kuickshow/src/kuickshow.cpp
+++ b/kuickshow/src/kuickshow.cpp
@@ -1228,14 +1228,14 @@ void KuickShow::initImlib()
if ( !id ) {
initImlibParams( idata, &par );
- qWarning("*** KuickShow: Whoops, can't initialize imlib, trying my own palettefile now.");
+ tqWarning("*** KuickShow: Whoops, can't initialize imlib, trying my own palettefile now.");
TQString paletteFile = locate( "data", "kuickshow/im_palette.pal" );
- // ### - does the qstrdup() cure the segfault in imlib eventually?
- char *file = qstrdup( paletteFile.local8Bit() );
+ // ### - does the tqstrdup() cure the segfault in imlib eventually?
+ char *file = tqstrdup( paletteFile.local8Bit() );
par.palettefile = file;
par.flags |= PARAMS_PALETTEFILE;
- qWarning("Palettefile: %s", par.palettefile );
+ tqWarning("Palettefile: %s", par.palettefile );
id = Imlib_init_with_params( x11Display(), &par );